@@ -52,6 +52,10 @@ RESERVED = (
     "new",
     "next",
     "nil",
+    "NIL",
+    "NULL",
+    "null",
+    "None",
     "not",
     "or",
     "private",
